aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--CHANGELOG.md4
-rw-r--r--build.gradle9
-rw-r--r--gradle.properties3
-rw-r--r--src/main/java/eu/olli/cowmoonication/command/MooCommand.java12
-rw-r--r--update.json6
5 files changed, 17 insertions, 17 deletions
diff --git a/CHANGELOG.md b/CHANGELOG.md
index 81daeb2..c17b237 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -3,7 +3,7 @@ All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).
-## [1.8.9-0.6.0] - unreleased
+## [1.8.9-0.6.0] - 05.07.2020
### Added
- Minecraft log file search `/moo search`
- Analyze minions on a private island `/moo analyzeIsland`
@@ -77,7 +77,7 @@ The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).
*Note:* The 'best friends' list is currently available via <kbd>ESC</kbd> > Mod Options > Cowmoonication > Config > bestFriends.
-[1.8.9-0.6.0]: https://github.com/cow-mc/Cowmoonication/compare/v1.8.9-0.5.0...master
+[1.8.9-0.6.0]: https://github.com/cow-mc/Cowmoonication/compare/v1.8.9-0.5.0...v1.8.9-0.6.0
[1.8.9-0.5.0]: https://github.com/cow-mc/Cowmoonication/compare/v1.8.9-0.4.0...v1.8.9-0.5.0
[1.8.9-0.4.0]: https://github.com/cow-mc/Cowmoonication/compare/v1.8.9-0.3.1...v1.8.9-0.4.0
[1.8.9-0.3.1]: https://github.com/cow-mc/Cowmoonication/compare/v1.8.9-0.3.0...v1.8.9-0.3.1
diff --git a/build.gradle b/build.gradle
index cbd91b2..c9883f2 100644
--- a/build.gradle
+++ b/build.gradle
@@ -35,7 +35,7 @@ minecraft {
replace "@VERSION@": project.version, "@MODNAME@": project.mod_name, "@MODID@": mod_id, "@PACKAGE@": project.group_package, "@GITURL@": project.git_url
replaceIn "${mod_name_no_spaces}.java"
-
+
// the mappings can be changed at any time, and must be in the following format.
// snapshot_YYYYMMDD snapshot are built nightly.
// stable_# stables are built at the discretion of the MCP team.
@@ -50,7 +50,7 @@ dependencies {
// or you may define them like so..
//compile "some.group:artifact:version:classifier"
//compile "some.group:artifact:version"
-
+
// real examples
//compile 'com.mod-buildcraft:buildcraft:6.0.8:dev' // adds buildcraft to the dev env
//compile 'com.googlecode.efficient-java-matrix-library:ejml:0.24' // adds ejml to the dev env
@@ -66,7 +66,6 @@ dependencies {
// for more info...
// http://www.gradle.org/docs/current/userguide/artifact_dependencies_tutorial.html
// http://www.gradle.org/docs/current/userguide/dependency_management.html
-
}
processResources {
@@ -82,9 +81,9 @@ processResources {
include 'mcmod.info'
// replace version, mcversion, modname, modid and giturl
- expand 'version':project.version, 'mcversion':project.minecraft.version, 'modname':project.mod_name, 'modid':mod_id, 'giturl':project.git_url
+ expand 'version': project.version, 'mcversion': project.minecraft.version, 'modname': project.mod_name, 'modid': mod_id, 'giturl': project.git_url
}
-
+
// copy everything else, that's not the mcmod.info
from(sourceSets.main.resources.srcDirs) {
exclude 'mcmod.info'
diff --git a/gradle.properties b/gradle.properties
index 34fe5b5..4f074fe 100644
--- a/gradle.properties
+++ b/gradle.properties
@@ -1,8 +1,9 @@
mod_name=Cowmoonication
group_package=eu.olli.cowmoonication
-mod_version=0.5.0
+mod_version=0.6.0
git_url=https://github.com/cow-mc/Cowmoonication/
mc_version=1.8.9
forge_version=11.15.1.2318-1.8.9
mappings_version=stable_22
+org.gradle.jvmargs=-Xmx2048M
diff --git a/update.json b/update.json
index 0c66c1e..e61163f 100644
--- a/update.json
+++ b/update.json
@@ -1,10 +1,10 @@
{
"homepage": "https://github.com/cow-mc/Cowmoonication/",
"1.8.9": {
- "1.8.9-0.5.0": "https://github.com/cow-mc/Cowmoonication/blob/master/CHANGELOG.md"
+ "1.8.9-0.6.0": "https://github.com/cow-mc/Cowmoonication/blob/master/CHANGELOG.md"
},
"promos": {
- "1.8.9-latest": "1.8.9-0.5.0",
- "1.8.9-recommended": "1.8.9-0.5.0"
+ "1.8.9-latest": "1.8.9-0.6.0",
+ "1.8.9-recommended": "1.8.9-0.6.0"
}
}
diff --git a/src/main/java/eu/olli/cowmoonication/command/MooCommand.java b/src/main/java/eu/olli/cowmoonication/command/MooCommand.java
index 4467167..9a73cbe 100644
--- a/src/main/java/eu/olli/cowmoonication/command/MooCommand.java
+++ b/src/main/java/eu/olli/cowmoonication/command/MooCommand.java
@@ -48,7 +48,7 @@ public class MooCommand extends CommandBase {
sendCommandUsage(sender);
return;
}
// sub commands: friends
if (args[0].equalsIgnoreCase("stalk")) {
if (args.length != 2) {
throw new WrongUsageException("/" + getCommandName() + " stalk <playerName>");
@@ -207,11 +207,11 @@ public class MooCommand extends CommandBase {
e.printStackTrace();
throw new MooCommandException("\u2716 An error occurred trying to open the mod's directory. I guess you have to open it manually \u00af\\_(\u30c4)_/\u00af");
}
+ } else if (args[0].equalsIgnoreCase("help")) {
+ sendCommandUsage(sender);
}
// "catch-all" remaining sub-commands
- else if (args[0].equalsIgnoreCase("help")) {
- sendCommandUsage(sender);
- } else {
+ else {
main.getChatHelper().sendMessage(EnumChatFormatting.RED, "Command " + EnumChatFormatting.DARK_RED + "/" + getCommandName() + " " + args[0] + EnumChatFormatting.RED + " doesn't exist. Use " + EnumChatFormatting.DARK_RED + "/" + getCommandName() + " help " + EnumChatFormatting.RED + "to show command usage.");
}
}
@@ -461,7 +461,7 @@ public class MooCommand extends CommandBase {
private void sendCommandUsage(ICommandSender sender) {
IChatComponent usage = new MooChatComponent("\u279C " + Cowmoonication.MODNAME + " commands:").gold().bold()
- .appendSibling(createCmdHelpSection(1, "Friends"))
+ .appendSibling(createCmdHelpSection(1, "Friends & other players"))
.appendSibling(createCmdHelpEntry("stalk", "Get info of player's status"))
.appendSibling(createCmdHelpEntry("stalkskyblock", "Get info of player's SkyBlock stats"))
.appendSibling(createCmdHelpEntry("analyzeIsland", "Analyze a SkyBlock private island"))
@@ -503,7 +503,7 @@ public class MooCommand extends CommandBase {
public List<String> addTabCompletionOptions(ICommandSender sender, String[] args, BlockPos pos) {
if (args.length == 1) {
return getListOfStringsMatchingLastWord(args,
- /* friends */ "stalk", "stalkskyblock", "skyblockstalk", "analyzeIsland", "add", "remove", "list", "nameChangeCheck", "toggle",
+ /* friends & other players */ "stalk", "stalkskyblock", "skyblockstalk", "analyzeIsland", "add", "remove", "list", "nameChangeCheck", "toggle",
/* miscellaneous */ "config", "search", "guiscale", "shrug", "apikey",
/* update mod */ "update", "updateHelp", "version", "directory",
/* help */ "help");
@@ -48,7 +48,7 @@ public class MooCommand extends CommandBase {
return;
}
- // sub commands: friends
+ // sub commands: friends & other players
if (args[0].equalsIgnoreCase("stalk")) {
if (args.length != 2) {